@@ -12,9 +12,11 @@ pub mod connection;
 pub mod counter;
 pub mod crypto;
 pub mod ct;
+pub mod datagram;
 pub mod endpoint;
 pub mod event;
 pub mod frame;
+pub mod havoc;
 pub mod inet;
 pub mod io;
 pub mod number;
