@@ -162,6 +162,8 @@ pub struct CubicCongestionController {
 type BytesInFlight = Counter<u32>;
 
 impl CongestionController for CubicCongestionController {
+    type PacketInfo = ();
+
     #[inline]
     fn congestion_window(&self) -> u32 {
         self.congestion_window as u32
@@ -192,6 +194,11 @@ impl CongestionController for CubicCongestionController {
         bytes_sent: usize,
         rtt_estimator: &RttEstimator,
     ) {
+        if bytes_sent == 0 {
+            // Packet was not congestion controlled
+            return;
+        }
+
         self.bytes_in_flight
             .try_add(bytes_sent)
             .expect("bytes sent should not exceed u32::MAX");
@@ -232,16 +239,17 @@ impl CongestionController for CubicCongestionController {
     }
 
     #[inline]
-    fn on_packet_ack(
+    fn on_ack(
         &mut self,
-        largest_acked_time_sent: Timestamp,
-        sent_bytes: usize,
+        newest_acked_time_sent: Timestamp,
+        bytes_acknowledged: usize,
+        _newest_acked_packet_info: Self::PacketInfo,
         rtt_estimator: &RttEstimator,
         ack_receive_time: Timestamp,
     ) {
         self.bytes_in_flight
-            .try_sub(sent_bytes)
-            .expect("sent bytes should not exceed u32::MAX");
+            .try_sub(bytes_acknowledged)
+            .expect("bytes_acknowledged should not exceed u32::MAX");
 
         if self.under_utilized {
             self.state.on_app_limited(ack_receive_time);
@@ -257,7 +265,7 @@ impl CongestionController for CubicCongestionController {
 
         // Check if this ack causes the controller to exit recovery
         if let State::Recovery(recovery_start_time, _) = self.state {
-            if largest_acked_time_sent > recovery_start_time {
+            if newest_acked_time_sent > recovery_start_time {
                 //= https://www.rfc-editor.org/rfc/rfc9002#section-7.3.2
                 //# A recovery period ends and the sender enters congestion avoidance
                 //# when a packet sent during the recovery period is acknowledged.
@@ -272,7 +280,7 @@ impl CongestionController for CubicCongestionController {
                 //# the number of bytes acknowledged when each acknowledgment is
                 //# processed.  This results in exponential growth of the congestion
                 //# window.
-                self.congestion_window += sent_bytes as f32;
+                self.congestion_window += bytes_acknowledged as f32;
 
                 if self.congestion_window >= self.slow_start.threshold {
                     //= https://www.rfc-editor.org/rfc/rfc8312#section-4.8
@@ -306,7 +314,7 @@ impl CongestionController for CubicCongestionController {
                 //      investigation and testing to evaluate if smoothed_rtt would be a better input.
                 let rtt = rtt_estimator.min_rtt();
 
-                self.congestion_avoidance(t, rtt, sent_bytes);
+                self.congestion_avoidance(t, rtt, bytes_acknowledged);
             }
         };
 
@@ -314,10 +322,12 @@ impl CongestionController for CubicCongestionController {
     }
 
     #[inline]
-    fn on_packets_lost(
+    fn on_packet_lost(
         &mut self,
         lost_bytes: u32,
+        _packet_info: Self::PacketInfo,
         persistent_congestion: bool,
+        _new_loss_burst: bool,
         timestamp: Timestamp,
     ) {
         debug_assert!(lost_bytes > 0);
